.. _index_toplevel:

=====================
Stalker Documentation
=====================

.. include:: about.rst

.. include:: contents.rst

.. include:: summary.rst

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`